==> fusenshi-0.7.5.tgz: fusenshi-0.7.5/src/net/fusenshiclient.h <==
/*
 * $Id: fusenshiclient.h,v 1.1 2004/04/01 08:53:12 daichi Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.1 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___FUSENSHICLIENT_H
#define ___FUSENSHICLIENT_H

#include "../include/fusenshidata.h"
#include "../include/serverlist.h"
#include "../include/propertydata.h"

class FusenshiClient
{
public:
    /**
     * ǥȥ饯
     */
    ~FusenshiClient();

public:
    /**
     * 䵻ǡޤ
     * 
     * @param pIP IP
     * @param pData 䵻ǡ
     * @return  true ᤹
     */
    static bool sendFusenshiData
        (const gchar* pIP, const GString* pData,
         const Glib::ustring& szNickName);

    /**
     * 䵻ǡޤ
     * 
     * @param netInfo 
     * @param data 䵻ǡ
     * @return  true ᤹
     */
    static bool sendFusenshiData
        (ServerList& serverList, const FusenshiData& data,
         const Glib::ustring& szNickName);
   
    /**
     * 䵻楯饤Ȥ¸߳ǧѥ֥ɥ㥹ȥѥåȤ
     * Фޤ
     * 
     * @param property 䵻ץѥƥ
     */
    static void sendServerInfoRequest(const PropertyData& property);
   
private:
    /**
     * 󥹥ȥ饯
     */
    FusenshiClient();
};

#endif

==> fusenshi-0.8.2.tgz: fusenshi-0.8.2/src/net/fusenshiclient.h <==
/*
 * $Id: fusenshiclient.h,v 1.3 2005/12/02 07:08:01 ozawa Exp $
 *
 * Copyright 2003- ONGS Inc. All rights reserved.
 * 
 * author: Masanori OZAWA (ozawa@ongs.co.jp)
 * version: $Revision: 1.3 $
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY ONGS INC ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL ONGS INC OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation are
 * those of the authors and should not be interpreted as representing official
 * policies, either expressed or implied, of the ONGS Inc.
 * 
 */

#ifndef ___FUSENSHICLIENT_H
#define ___FUSENSHICLIENT_H

#include "../include/fusenshidata.h"
#include "../include/serverlist.h"
#include "../include/propertydata.h"

class FusenshiClient
{
public:
    /**
     * ǥȥ饯
     */
    ~FusenshiClient();

public:
    /**
     * 䵻ǡޤ
     * 
     * @param pIP IP
     * @param pData 䵻ǡ
     * @param szNickName ˥å͡
     * @param bSSL SSLŹ沽̿Ѥ true ꤷޤ
     * @return  true ᤹
     */
    static bool sendFusenshiData
        (const gchar* pIP, const char* pData,
         const Glib::ustring& szNickName, bool bSSL);

    /**
     * 䵻ǡޤ
     * SSL̵̿ͭϥФγĥ󤫤ꤷޤ
     * 
     * @param netInfo 
     * @param data 䵻ǡ
     * @param szNickName ˥å͡
     * @return  true ᤹
     */
    static bool sendFusenshiData
        (ServerList& serverList, const FusenshiData& data,
         const Glib::ustring& szNickName);
   
    /**
     * 䵻楯饤Ȥ¸߳ǧѥ֥ɥ㥹ȥѥåȤ
     * Фޤ
     * 
     * @param property 䵻ץѥƥ
     */
    static void sendServerInfoRequest(const PropertyData& property);
   
private:
    /**
     * 󥹥ȥ饯
     */
    FusenshiClient();
};

#endif
